***************************************************************
**Regressions
***************************************************************

***************************************************************
*Low-cost Regressions
***************************************************************



import delimited "$final_data_dir/full_local.csv", clear



*  2: Generate Variables **************************************

gen clean_utcdatetime = trim(day_hr)
gen clean_datetime = regexs(1) if regexm(clean_utcdatetime, "([0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2})")

gen double datetime = clock(clean_datetime, "YMD hms")

format datetime %tc


* Extract year and month
extrdate month month = datetime 
extrdate year year = datetime 
extrdate week week = datetime 
extrdate day day = datetime 
extrdate dow dow = datetime 
gen date = mdy(month, day, year)
format date %td
generate hour = hh(datetime)


*Drop values after May 12th for any year 
gen invalid_dates = (month > 5) | (month == 5 & day > 12)

drop if invalid_dates == 1
drop if month==1 & day<23

* Generate additional variables

gen post_mar15 = (month == 3 & day >= 14 ) |(month>=4)

gen covid  = year==2020

* Generate dummy variables for each location code
gen fc000 = locationcode == "DAQ-F-C-000"
gen lpaosf = locationcode == "LPAOSF"
gen fc001 = locationcode == "DAQ-F-C-001"

* Generate a variable for the day of the year
gen doy = doy(date)
	   

* Encode the location code
encode locationcode, gen(locationcode_num)
sort locationcode_num datetime


*************
**HOURLY LEVEL
*************
// bys locationcode_num year: gen tot=_N

// Winsorizing
local iv_list "avg_pm25_cf1 barkjohn jaffe_new local_hourly satellite_hourly belair_calibration pikine_calibration"
forvalues i = 1/7 {
    // Define the independent variable for this iteration
    local iv : word `i' of `iv_list'
    
    winsor2 `iv', cuts (0 99) suffix(_w) label 
}
	


label variable avg_pm25_cf1_w "Low-cost"
label variable barkjohn_w "Barkjohn"
label variable jaffe_new_w "Jaffe"
label variable local_hourly_w "Local"
label variable satellite_hourly_w "Satellite"
// label variable local_hourly_monitor_w "Local (monitor humidity+temp)"


label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
// label variable post_mar15#covid "2020*Policy Period (March 14-May 12)"
label variable temp "Temperature"
label variable humidity "Humidity"


local iv_list "avg_pm25_cf1_w barkjohn_w jaffe_new_w local_hourly_w satellite_hourly_w"
// Loop over the list of independent variables
forvalues i = 1/5 {
    // Define the independent variable for this iteration
    local iv : word `i' of `iv_list'
    
    
    // Run regression and save to tab_8_i
    eststo: reg `iv' post_mar15 covid post_mar15##covid  temp humidity i.hour i.week i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
    eststo tab_8`i'

    // Summarize avg_pm25_atm
    summarize `iv' if post_mar15 == 0 & year == 2020 // & `iv' < `p99'
    
    // Store the mean value in a local macro
    estadd scalar avg `r(mean)'
    
    // Store the coefficient value for 1.post_mar15#1.covid
    estimates restore tab_8`i'
    estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
    
    // Calculate the 'percent' variable
    estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
//     di "Value of percent scalar: " percent
    
    // Output regression results
    esttab tab_8`i', label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
        scalars("avg Average" "percent Percent") ///
        nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
}


	

*Table 1 - Calibration Coefficients comparing Regulatory and nearby Purple Air monitors (Hourly) 
esttab tab_81 tab_82 tab_83 tab_84 tab_85 using "$outputs/coefficient_comparison_hourly.tex", ///
    prehead("\begin{table}[htbp]\centering \\ \caption{Comparison of Low-cost Correction Regression Coefficients (Hourly, 2020 \& 2023) \label{coefficient-comparison-hourly}} \\ \begin{tabular}{l*{5}{c}} \toprule  ") ///
 replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
mtitles("Low-cost" "Barkjohn" "\shortstack{\textbf{\underline{Type of Correction}}\\Jaffe}" "Local" "Satellite") ///
    scalars("avg Average" "percent \% of Average") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs  ///
postfoot("\bottomrule \multicolumn{6}{p{16cm}}{\footnotesize \textbf{Note}: Controlling for temperature and humidity, with hourly, weekly, monthly, day-of-week and monitor fixed effects. The 'Average' is based off the pre-Covid average in 2020. Jaffe correction uses PM1/10 ratio to identify dust events. Winsorizing outliers at 99th percentile. Low-cost refers to raw Purple Air data using the cf=1 formula. Barkjohn and Jaffe are Purple Air corrections based on previous literature. Local and Satellite corrections are based on calibrating the Purple Air data on co-located regulatory and satellite data, respectively. \sym{*} \(p<0.05\), \sym{**} \(p<0.01\), \sym{***} \(p<0.001\).} \\ \end{tabular} \\\end{table}") ///
    fragment

	
*local cal
local iv_list "avg_pm25_cf1_w local_hourly_w belair_calibration_w pikine_calibration_w"
// Loop over the list of independent variables
forvalues i = 1/4 {
    // Define the independent variable for this iteration
    local iv : word `i' of `iv_list'
    
    
    // Run regression and save to tab_8_i
    eststo: reg `iv' post_mar15 covid post_mar15##covid  temp humidity i.hour i.week i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
    eststo local_cal`i'

    // Summarize avg_pm25_atm
    summarize `iv' if post_mar15 == 0 & year == 2020 // & `iv' < `p99'
    
    // Store the mean value in a local macro
    estadd scalar avg `r(mean)'
    
    // Store the coefficient value for 1.post_mar15#1.covid
    estimates restore local_cal`i'
    estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
    
    // Calculate the 'percent' variable
    estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
//     di "Value of percent scalar: " percent
    
    // Output regression results
    esttab local_cal`i', label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
        scalars("avg Average" "percent Percent") ///
        nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
}


	



*Robustness checks

eststo: reg local_hourly_w post_mar15 covid post_mar15##covid  temp humidity i.hour i.week i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | (year == 2022 ) |((year == 2023) )), robust coeflegend
eststo hourly_local_2017

summarize local_hourly_w if post_mar15 == 0 & year == 2020 // & `iv' < `p99'

estadd scalar avg `r(mean)'
estimates restore hourly_local_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab  hourly_local_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
	
	
eststo: reg avg_pm25_cf1_w post_mar15 covid post_mar15##covid  temp humidity i.hour i.week i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | (year == 2022 ) |((year == 2023) )), robust coeflegend
eststo hourly_pa_2017

summarize avg_pm25_cf1_w if post_mar15 == 0 & year == 2020 // & `iv' < `p99'

estadd scalar avg `r(mean)'
estimates restore hourly_pa_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab  hourly_pa_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)


*************
**DAILY LEVEL
*************
*collapse daily
collapse (mean)   avg_pm25_cf1 jaffe_original jaffe_new barkjohn temp precip humidity local_daily local_hourly satellite_daily covid post_mar15  month dow year day week lpaosf fc001  (max) avg_pm25_cf1_max=avg_pm25_cf1 avg_pm25_max=avg_pm25_atm jaffe_original_max=jaffe_original barkjohn_max=barkjohn local_daily_max=local_daily local_hourly_max=local_hourly , by(locationcode_num date) 



// Winsorizing
local iv_list "avg_pm25_cf1 barkjohn jaffe_new local_daily satellite_daily avg_pm25_cf1_max local_daily_max local_hourly_max"
forvalues i = 1/8 {
    // Define the independent variable for this iteration
    local iv : word `i' of `iv_list'
    
    winsor2 `iv', cuts (0 99) suffix(_w) label 
}
	
	
	
label variable avg_pm25_cf1_w "Low-cost"
label variable barkjohn_w "Barkjohn"
label variable jaffe_new_w "Jaffe"
label variable local_daily_w "Local"
label variable satellite_daily_w "Satellite"
label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
label variable temp "Temperature"
label variable humidity "Humidity"

// bys locationcode_num year: gen tot_day=_N


local iv_list "avg_pm25_cf1_w barkjohn_w jaffe_new_w local_daily_w satellite_daily_w"
// Loop over the list of independent variables
forvalues i = 1/5 {
    // Define the independent variable for this iteration
    local iv : word `i' of `iv_list'
 
    // Run regression and save to tab_8_i
    eststo: reg `iv' post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
    eststo tab_8_daily`i'

    // Summarize avg_pm25_atm
    summarize `iv' if post_mar15 == 0 & year == 2020 // & `iv' < `p99'
    
    // Store the mean value in a local macro
    estadd scalar avg `r(mean)'
    
    // Store the coefficient value for 1.post_mar15#1.covid
    estimates restore tab_8_daily`i'
    estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
    
    // Calculate the 'percent' variable
    estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
//     di "Value of percent scalar: " percent
    
    // Output regression results
    esttab tab_8_daily`i', label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
        scalars("avg Average" "percent Percent") ///
        nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
}


	
	

*2020-2023

eststo: reg local_daily_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | (year == 2022 ) |((year == 2023))), robust coeflegend
eststo daily_local_2017

summarize local_daily_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore daily_local_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab daily_local_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)

eststo: reg avg_pm25_cf1_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.locationcode_num ///
        if ((year == 2020 ) | (year == 2022 ) |((year == 2023))), robust coeflegend
eststo daily_pa_2017

summarize avg_pm25_cf1_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore daily_pa_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab daily_pa_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)


*************
**DAILY MAX 2023 - Table 6, PA 
*************
label variable avg_pm25_cf1_max_w "Low-cost"
label variable local_daily_max_w "Local Calibration"



eststo: reg avg_pm25_cf1_max_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.locationcode_num ///
        if ((year==2020 | year==2023)), robust coeflegend
eststo max_pa

summarize avg_pm25_cf1_max_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore max_pa
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
esttab max_pa, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
	scalars("avg Average" "percent Percent") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)

	
// eststo: reg local_daily_max_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.locationcode_num ///
eststo: reg local_hourly_max_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.locationcode_num ///
        if ((year==2020 | year==2023)), robust coeflegend
eststo max_local

// summarize local_daily_max_w if post_mar15 == 0 & year == 2020 
summarize local_hourly_max_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore max_local
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
esttab max_local, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
	scalars("avg Average" "percent Percent") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)

	


	


***************************************************************
*CGQA - Making panel dataset and controlling for monitor fixed effects
***************************************************************


// import delimited "$Niall_dir\DIME-Senegal\datawork\Air_Quality\DataSets\Secondary\CGQA\processed\cgqa_hourly_pikine.csv", clear
import delimited "$raw_data_dir/cgqa_hourly.csv", clear



gen clean_utcdatetime = trim(day_hr)
gen double datetime = clock(clean_utcdatetime, "YMD hms")

format datetime %tc

keep pm25_reliable_µgm pm25_belair_µgm pm25_guediawaye_µgm pm25_republique_µgm pm25_dakar_µgm pm25_pikine_µgm datetime temp precip humidity

* Rename columns to just locations
rename pm25_belair_µgm pm25belair
rename pm25_guediawaye_µgm pm25guediawaye
rename pm25_republique_µgm pm25republique
rename pm25_dakar_µgm pm25dakar
rename pm25_pikine_µgm pm25pikine
rename pm25_reliable_µgm pm25reliable

* Reshape from wide to long format
reshape long pm25, i(datetime) j(monitor) string




* Extract year and month
extrdate month month = datetime 
*drop year
extrdate year year = datetime 
extrdate week week = datetime 
extrdate day day = datetime 
extrdate dow dow = datetime 
*drop hour
generate hour = hh(datetime)
*drop date
gen date = mdy(month, day, year)
format date   %td 
*tsset datetime, delta(1 hour)


* Generate a flag for dates on or after 12th May in any year
gen after_may_12 = (month > 5) | ((month == 5) & (day >= 12))

*Drop values after May 12th for any year 
gen invalid_dates = (month > 5) | (month == 5 & day > 12)
replace invalid_dates = 1 if (month ==1 ) & (day <= 22)

drop if invalid_dates == 1


* Define treatment periods for any year
gen post_mar15 = (month == 3 & day >= 14 ) |(month>=4)

gen covid  = (year == 2020)

encode monitor, gen(monitor_num)

*  3: Regressions **************************************

*************
**HOURLY LEVEL
*************

*drop aggregated monitors 
drop if monitor == "dakar" & monitor == "reliable"
winsor2 pm25, cuts (0 99) suffix(_w) label

label variable pm25_w "Regulatory"
label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
label variable temp "Temperature"
label variable humidity "Humidity"

eststo: reg pm25_w post_mar15 covid post_mar15##covid  temp humidity i.monitor_num i.hour i.week i.month i.dow  ///
    if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
eststo hourly_reg
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore hourly_reg
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab hourly_reg, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
//         scalars("avg Average" "percent Percent") ///
//         nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
		
// esttab  tab_84 hourly_reg, keep(post_mar15 covid 1.post_mar15#1.covid)


********2017-20

eststo: reg pm25_w post_mar15 covid post_mar15##covid temp humidity i.monitor_num i.hour i.week i.month i.dow  ///
    if (year>=2017 | year<=2020), robust coeflegend
eststo hourly_reg_2017
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore hourly_reg_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
*table 4, b
// esttab  hourly_reg_2017 hourly_local_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)





*************
**Max Hourly Averages 
*************	
*not included in paper

*************
**DAILY  LEVEL
*************
collapse (mean) pm25   post_mar15 covid  temp humidity  month dow year day week  (max) pm25_max=pm25  , by(monitor_num date) 

*Daily average, 2020 &2023

winsor2 pm25, cuts (0 99) suffix(_w) label

label variable pm25_w "Regulatory"
label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
label variable temp "Temperature"
label variable humidity "Humidity"

eststo: reg pm25_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.monitor_num if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
eststo daily_reg
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore daily_reg
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab daily_reg, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
//         scalars("avg Average" "percent Percent") ///
//         nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
	
// esttab  tab_8_daily4 daily_reg, keep(post_mar15 covid 1.post_mar15#1.covid) ///
// 	   scalars("avg Average" "percent \% of Average")



*Daily average, 2017-20

eststo: reg pm25_w post_mar15 covid post_mar15##covid temp humidity i.month i.dow i.monitor_num  ///
    if (year>=2017 | year<=2020), robust coeflegend
eststo daily_reg_2017
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore daily_reg_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
*table 4, b
*again, there is no daily PA estimate to compare to (below is hourly)
// esttab  daily_reg_2017 daily_local_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)


*************
**DAILY  Max LEVEL
*************

winsor2 pm25_max, cuts (0 99) suffix(_w) label

label variable pm25_max_w "Regulatory"
label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
label variable temp "Temperature"
label variable humidity "Humidity"

*2020,2023
eststo: reg pm25_max_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow i.monitor_num ///
        if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
eststo max_reg

summarize pm25_max_w if post_mar15 == 0 & year == 2020 

estadd scalar avg `r(mean)'
estimates restore max_reg
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
// esttab max_reg, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
//
// esttab max_reg max_local, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
//

***************************************************************
*Merra-2 - 2017-2023
***************************************************************

import delimited "$final_data_dir/covid_merra.csv", clear


gen clean_utcdatetime = trim(day_hr)
gen double datetime = clock(clean_utcdatetime, "YMD hms")

format datetime %tc



* Extract year and month
extrdate month month = datetime 
// drop year
extrdate year year = datetime 
extrdate week week = datetime 
extrdate day day = datetime 
extrdate dow dow = datetime 
// drop hour
generate hour = hh(datetime)
// drop date
gen date = mdy(month, day, year)


****

* Generate a flag for dates on or after 12th May in any year
gen after_may_12 = (month > 5) | ((month == 5) & (day >= 12))

*Drop values after May 12th for any year 
gen invalid_dates = (month > 5) | (month == 5 & day > 12)
replace invalid_dates = 1 if (month ==1 ) & (day <= 22)

drop if invalid_dates == 1


* Define treatment periods for any year
gen post_mar15 = (month == 3 & day >= 14 ) |(month>=4)

gen covid  = (year == 2020)



*  3: Regressions **************************************


*************
**HOURLY LEVEL
*************
winsor2 pm25, cuts (0 99) suffix(_w) label

label variable pm25_w "Satellite"
label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
label variable temp "Temperature"
label variable humidity "Humidity"

eststo: reg pm25_w post_mar15 covid post_mar15##covid  temp humidity i.hour i.week i.month i.dow  ///
    if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
eststo hourly_sat
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore hourly_sat
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
esttab hourly_sat, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
        scalars("avg Average" "percent Percent") ///
        nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
		
esttab  tab_84 hourly_reg hourly_sat, keep(post_mar15 covid 1.post_mar15#1.covid)

esttab   hourly_reg hourly_sat tab_81 tab_84 using "$outputs/reg_hourly_2020+2023.tex", replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    addnotes("Data is aggregated hourly. Controlling for temperature and humidity, with hourly, weekly, monthly, day-of-week and monitor fixed effects" "The 'Average' is based off the pre-Covid average in 2020"  "Contains data from 22nd January to 12th May for 2020 and 2023""The cf=1 formula is used for Low-cost measurements" "Regulatory data comes from monitors operated by the CGQA" "Satellite PM2.5 estimates come from MERRA-2"  "Winsorizing outliers at 99th percentile" ) ///
    scalars("avg Average" "percent \% of Average") ///
    title(" Impact of Covid Mobility Restrictions on Air Pollution Measures (Hourly Averages, 2020 \& 2023) \label{reg-hourly-2020-2023}") ///
	 coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
	 mtitles("Regulatory" "Satellite" "Low-cost" "PA Local Calibration") ///
	nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs nonotes 
	

********
*2017-20, hourly
********

eststo: reg pm25_w post_mar15 covid post_mar15##covid temp humidity i.hour i.week i.month i.dow  ///
    if (year>=2017 | year<=2020), robust coeflegend
eststo hourly_sat_2017
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore hourly_sat_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
*table 4, b
// esttab  hourly_reg_2017 hourly_sat_2017 hourly_local_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
// 	scalars("avg Average" "percent Percent") ///
// 	 mtitles("Regulatory (2017-2020)" "Satellite (2017-2020)" "PA Local Calibration (2020-2023)") ///
//     nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
//	

*Table A4: Impact of Covid Mobility Restrictions on Air Pollution Measures - Panel C
esttab  hourly_reg_2017 hourly_sat_2017 hourly_pa_2017 hourly_local_2017 using "$outputs/reg_hourly_2017.tex", replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    addnotes("Regulatory and Satellite data is from 2017-2020. Low-cost data is from 2020-2023" "Controlling for temperature and humidity, with hourly, weekly, monthly, day-of-week and monitor fixed effects" "Contains data from 22nd January to 12th May for 2020 and 2023" "The 'Average' is based off the pre-Covid average in 2020" "The cf=1 formula is used for Low-cost measurements" "Regulatory data comes from monitors operated by the CGQA" "Satellite PM2.5 estimates come from MERRA-2"  "Winsorizing outliers at 99th percentile" ) ///
    scalars("avg Average" "percent \% of Average") ///
    title(" Impact of Covid Mobility Restrictions on Air Pollution Measures (Hourly Averages, 3-year) \label{reg-hourly-2017}") ///
	 coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
	 mtitles("Regulatory" "Satellite""Low-cost" "PA Local Calibration") ///
	nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs nonotes 
	





*************
**Max Hourly Averages 
*************	
*not included in paper
	
*************
**DAILY LEVEL
*************

collapse (mean) pm25  post_mar15 covid  temp humidity precip  month dow year day week  (max) pm25_max=pm25 , by( date) 



*Daily average, 2020 &2023

winsor2 pm25, cuts (0 99) suffix(_w) label

label variable pm25_w "Satellite"
label variable post_mar15 "Policy Period (Mar 14-May 12)"
label variable covid "2020"
label variable temp "Temperature"
label variable humidity "Humidity"

eststo: reg pm25_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
eststo daily_sat
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore daily_sat
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
esttab daily_sat, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
        scalars("avg Average" "percent Percent") ///
        nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)

esttab   daily_reg daily_sat tab_8_daily4, keep(post_mar15 covid 1.post_mar15#1.covid)


	


*Daily average, 2017-20

eststo: reg pm25_w post_mar15 covid post_mar15##covid temp humidity i.month i.dow  ///
    if (year>=2017 | year<=2020), robust coeflegend
eststo daily_sat_2017
summarize pm25_w if post_mar15 == 0 & year == 2020 
estadd scalar avg `r(mean)'
estimates restore daily_sat_2017
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace 
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100

*Daily 3 year regression

esttab  daily_reg_2017 daily_sat_2017 daily_local_2017, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
	scalars("avg Average" "percent Percent") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)
	

    
* Table A4 - Panel B
esttab daily_reg daily_sat tab_8_daily1 tab_8_daily4 using "${outputs}/reg_daily_2020+2023.tex", ///
    prehead("\begin{table}[htbp]\centering \\ \caption{Impact of Covid Mobility Restrictions on Air Pollution Measures (Daily Averages) \label{reg-daily-combined}} \\ \begin{tabular}{l*{4}{c}} \hline\hline  ") ///
 replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
    mtitles("Regulatory" "Satellite" "Low-cost" "PA Local Calibration") ///
    scalars("avg Average" "percent \% of Average") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs  ///
    posthead("\hline \\ \multicolumn{5}{c}{\textbf{\underline{Panel A: 2020 \& 2023}}} \\\\[-1ex]") ///
    fragment


* Table A4 - Panel D
esttab  daily_reg_2017 daily_sat_2017 daily_pa_2017 daily_local_2017 using "$outputs/reg_daily_2017.tex", replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    addnotes("Regulatory and Satellite data is from 2017-20202. Low-cost data is from 2020-2023" "Controlling for temperature and humidity, with monthly, day-of-week and monitor fixed effects" "The 'Average' is based off the pre-Covid average in 2020" "Contains data from 22nd January to 12th May for each year" "Winsorizing outliers at 99th percentile" "The cf=1 formula is used for Low-cost measurements") ///
    scalars("avg Average" "percent \% of Average") ///
    title("Impact of Covid Mobility Restrictions on Air Pollution Measures (Daily Averages, 3-year) \label{reg-daily-2017}") ///
	 coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
	 mtitles("Regulatory" "Satellite" "Low-cost" "PA Local Calibration") ///
	nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs nonotes	
	
*************
**DAILY  Max LEVEL
*************

winsor2 pm25_max, cuts (0 99) suffix(_w) label

label variable pm25_max_w "Satellite"


*2020,2023
eststo: reg pm25_max_w post_mar15 covid post_mar15##covid  temp humidity i.month i.dow  ///
        if ((year == 2020 ) | ((year == 2023) )), robust coeflegend
eststo max_sat

summarize pm25_max_w if post_mar15 == 0 & year == 2020 

estadd scalar avg `r(mean)'
estimates restore max_sat
estadd scalar coef_post_mar15_covid = _b[1.post_mar15#1.covid], replace
estadd scalar percent = (e(coef_post_mar15_covid) / e(avg))*100
esttab max_sat, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
	scalars("avg Average" "percent Percent") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)

esttab max_reg max_sat max_local, label keep(post_mar15 covid 1.post_mar15#1.covid) noobs ///
	scalars("avg Average" "percent Percent") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f)


	

* Table A4 - Panel A
esttab max_reg max_sat max_pa max_local using "${outputs}/max_daily_2020+2023.tex", ///
    prehead("\begin{table}[htbp]\centering \\ \caption{Impact of Covid Mobility Restrictions on Air Pollution Measures (Daily Maximum, 2020 \& 2023)  \label{max-daily-2020-2023}} \\ \begin{tabular}{l*{5}{c}} \toprule  ") ///
 replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
	 mtitles("Regulatory" "Satellite" "Low-cost" "PA Local Calibration") ///
    scalars("avg Average" "percent \% of Average") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs  ///
postfoot("\bottomrule \multicolumn{6}{p{16cm}}{\footnotesize \textbf{Note}: The maximum represents the maximum hourly value for each day. Controlling for temperature and humidity, with hourly, weekly, monthly, day-of-week and monitor fixed effects. The 'Average' is based off the pre-Covid average in 2020. Contains data from 22nd January to 12th May for 2020 and 2023. Winsorizing outliers at 99th percentile. Regulatory data comes from monitors operated by the CGQA. Satellite PM2.5 estimates come from MERRA-2. Low-cost refers to raw Purple Air data using the cf=1 formula. The Local calibration is based on calibrating the Purple Air data on co-located regulatory data. \sym{*} \(p<0.05\), \sym{**} \(p<0.01\), \sym{***} \(p<0.001\).} \\ \end{tabular} \\\end{table}") ///
    fragment
	



*Table 5  - Comparison of Different Low-cost Calibration Coefficients (Hourly, 2020 & 2023)
esttab hourly_reg local_cal2 local_cal3 local_cal4  using "$outputs/local_calibration.tex",  ///
    prehead("\begin{table}[htbp]\centering \\ \caption{Comparison of Low-cost Calibration Regression Coefficients (Hourly, 2020 \& 2023) \label{local-calibration-hourly}} \\ \begin{tabular}{l*{5}{c}} \toprule  ") ///
 replace label keep(post_mar15 covid 1.post_mar15#1.covid) noobs nonumbers compress ///
    coeflabels(1.post_mar15#1.covid "Policy Period (March 14-May 12)*2020") ///
mtitles("Regulatory" "Local" "\shortstack{\textbf{\underline{Type of Correction}}\\Bel-air}" "Pikine") ///
    scalars("avg Average" "percent \% of Average") ///
    nocons sfmt(%9.2f) b(%9.2f) se(%9.2f) interaction("*") type booktabs  ///
postfoot("\bottomrule \multicolumn{6}{p{16cm}}{\footnotesize \textbf{Note}: Controlling for temperature and humidity, with hourly, weekly, monthly, day-of-week and monitor fixed effects. The 'Average' is based off the pre-Covid average in 2020. Jaffe correction uses PM1/10 ratio to identify dust events. Winsorizing outliers at 99th percentile. Low-cost refers to raw Purple Air data using the cf=1 formula. Barkjohn and Jaffe are Purple Air corrections based on previous literature. Local and Satellite corrections are based on calibrating the Purple Air data on co-located regulatory and satellite data, respectively. \sym{*} \(p<0.05\), \sym{**} \(p<0.01\), \sym{***} \(p<0.001\).} \\ \end{tabular} \\\end{table}") ///
    fragment
	
******************************************
* END OF SCRIPT
******************************************	